@@ -262,10 +262,8 @@ class ctable(object):
         # Guess the kind of columns input
         calist, nalist, ratype = False, False, False
         if type(columns) in (tuple, list):
-            calist = [type(v) for v in columns] == \
-                     [bcolz.carray for v in columns]
-            nalist = [type(v) for v in columns] == \
-                     [np.ndarray for v in columns]
+            calist = all(isinstance(v, bcolz.carray) for v in columns)
+            nalist = all(isinstance(v, np.ndarray) for v in columns)
         elif isinstance(columns, np.ndarray):
             ratype = hasattr(columns.dtype, "names")
             if ratype:
@@ -311,7 +309,12 @@ class ctable(object):
     def open_ctable(self):
         """Open an existing ctable on-disk."""
         if self.mode == 'r' and not os.path.exists(self.rootdir):
-            raise KeyError("Disk-based ctable opened with `r`ead mode yet `rootdir` does not exist")
+            raise KeyError(
+                "Disk-based ctable opened with `r`ead mode "
+                "yet `rootdir='{rootdir}'` does not exist".format(
+                    rootdir=self.rootdir,
+                )
+            )
 
         # Open the ctable by reading the metadata
         self.cols.read_meta_and_open()
@@ -346,13 +349,16 @@ class ctable(object):
         # Guess the kind of cols input
         calist, nalist, sclist, ratype = False, False, False, False
         if type(cols) in (tuple, list):
-            calist = [type(v) for v in cols] == [bcolz.carray for v in cols]
-            nalist = [type(v) for v in cols] == [np.ndarray for v in cols]
+            calist = all(isinstance(v, bcolz.carray) for v in cols)
+            nalist = all(isinstance(v, np.ndarray) for v in cols)
             if not (calist or nalist):
                 # Try with a scalar list
                 sclist = True
         elif isinstance(cols, np.ndarray):
             ratype = hasattr(cols.dtype, "names")
+        elif isinstance(cols, np.void):
+            ratype = hasattr(cols.dtype, "names")
+            sclist = True
         elif isinstance(cols, bcolz.ctable):
             # Convert int a list of carrays
             cols = [cols[name] for name in self.names]
@@ -476,9 +482,9 @@ class ctable(object):
 
         kwargs.setdefault('cparams', self.cparams)
 
-        if isinstance(newcol, bcolz.carray) and \
-                        self.rootdir is not None and \
-                        newcol.rootdir is not None:
+        if (isinstance(newcol, bcolz.carray) and
+            self.rootdir is not None and
+            newcol.rootdir is not None):
             # a special case, where you have a disk-based carray is inserted in a disk-based ctable
             if move:  # move the the carray
                 shutil.move(newcol.rootdir, col_rootdir)
@@ -1069,7 +1075,7 @@ class ctable(object):
         elif type(key) is list:
             if len(key) == 0:
                 return np.empty(0, self.dtype)
-            strlist = [type(v) for v in key] == [str for v in key]
+            strlist = all(isinstance(v, str) for v in key)
             # Range of column names
             if strlist:
                 cols = [self.cols[name] for name in key]
@@ -1088,7 +1094,7 @@ class ctable(object):
                 return self._where(key)
             elif np.issubsctype(key, np.int_):
                 # An integer array
-                return np.array([self[i] for i in key], dtype=self.dtype)
+                return np.array([tuple(self[i]) for i in key], dtype=self.dtype)
             else:
                 raise IndexError(
                     "arrays used as indices must be integer (or boolean)")
