@@ -14,12 +14,11 @@ import tempfile
 
 import numpy as np
 from numpy.testing import assert_array_equal, assert_allclose
-from bcolz.tests.common import MayBeDiskTest, TestCase, unittest, skipUnless
+from bcolz.tests.common import (
+        MayBeDiskTest, TestCase, unittest, skipUnless, SkipTest ) 
 import bcolz
-from bcolz.py2help import xrange, PY2
+from bcolz.py2help import xrange, PY2, Mock
 import pickle
-import os
-from mock import Mock
 
 
 class createTest(MayBeDiskTest):
@@ -223,6 +222,21 @@ class persistentTest(MayBeDiskTest, TestCase):
         ra = np.rec.fromarrays([a[:], b[:]]).view(np.ndarray)
         assert_array_equal(t[:], ra, "ctable values are not correct")
 
+    def test01d(self):
+        """Testing ctable opening in "r" mode with nonexistent directory"""
+        tempdir = tempfile.mkdtemp(prefix='bcolz-test01d')
+        non_existent_root = os.path.join(tempdir, 'not/a/real/path')
+        expected_message = (
+            "Disk-based ctable opened with `r`ead mode "
+            "yet `rootdir='{rootdir}'` does not exist".format(
+                rootdir=non_existent_root,
+            )
+        )
+
+        with self.assertRaises(KeyError) as ctx:
+            bcolz.ctable(rootdir=non_existent_root, mode='r')
+        self.assertEqual(ctx.exception.args[0], expected_message)
+
 
 class add_del_colTest(MayBeDiskTest):
 
@@ -672,6 +686,27 @@ class appendTest(MayBeDiskTest):
         ra = np.fromiter(((i, i * 2.) for i in xrange(N + 10)), dtype='i4,f8')
         assert_array_equal(t[:], ra, "ctable values are not correct")
 
+    def test05(self):
+        """Testing append() with void types"""
+        N = 10
+        ra = np.fromiter(((i, i * 2.) for i in xrange(N)), dtype='i4,f8')
+        t = bcolz.ctable(ra[:-1], rootdir=self.rootdir)
+        t.append(ra[-1])
+        assert_array_equal(t[:], ra, "ctable values are not correct")
+
+    def test06(self):
+        """Extracting rows from table with np.object column"""
+        N = 4
+        dtype = np.dtype([("a", np.object), ("b", np.uint8), ("c", np.int32), 
+            ("d", np.float32) ])
+        with bcolz.ctable(np.empty(0, dtype=dtype), rootdir=self.rootdir) as t:
+            for i in xrange(N):
+                t.append((str(i), i*2, i*4, i*8))
+            result = t[np.array([1, 0, 2])]
+            assert_array_equal(result[0], t[1])
+            assert_array_equal(result[1], t[0])
+            assert_array_equal(result[2], t[2])
+
 
 class appendMemoryTest(appendTest, TestCase):
     disk = False
@@ -2124,6 +2159,20 @@ class FlushDiskTest(MayBeDiskTest, TestCase):
                          rootdir=self.rootdir, auto_flush=False)
         self.assertFalse(t.auto_flush)
 
+    def test_repr_after_appending(self):
+        data = np.array([('data1', 1), ('data2', 2), ('data3', 3)],
+                        dtype=[('a', 'object'), ('b', 'int64')])
+        t = bcolz.ctable(data[:0].copy())
+        t.append(data)
+        self.assertTrue(bool(repr(t)))
+
+    def test_slice_after_appending(self):
+        data = np.array([('data1', 1), ('data2', 2), ('data3', 3)],
+                        dtype=[('a', 'object'), ('b', 'int64')])
+        t = bcolz.ctable(data[:0].copy())
+        t.append(data)
+        self.assertTrue((t[:1] == data[:1]).all())
+
 
 class ContextManagerTest(MayBeDiskTest, TestCase):
     disk = True
@@ -2143,6 +2192,17 @@ class ContextManagerTest(MayBeDiskTest, TestCase):
 
         assert_array_equal(expected, received)
 
+class ImportTest(TestCase):
+
+     @SkipTest 
+     def test_fork(self):
+            
+        if os.name == 'posix':
+            pid = os.fork()
+            # terminate nose on child process
+            if not pid:
+                with self.assertRaises(SystemExit):
+                    exit()
 
 if __name__ == '__main__':
     unittest.main(verbosity=2)
